﻿using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;

using MuScreenManager;

namespace TestGame
{
    /// <summary>
    /// Example of how to use MenuScreen
    /// </summary>
    class TestMenuScreen : MenuScreen
    {
        /// <summary>
        /// Constructor used to add a header to the page using the built in header drawing
        /// </summary>
        public TestMenuScreen()
            : base("Game!")
        { }

        /// <summary>
        /// Initialize cn be used to generate the MenuItems, add a consequence to selecting them and add them to the page drawing
        /// </summary>
        public override void Initialize()
        {
            //Generate the MenuItems
            MenuItem item1 = new MenuItem("Game!", new Vector2(screenManager.ScreenDimensions.X / 2, 100), screenManager);
            MenuItem item2 = new MenuItem("Close!", new Vector2(screenManager.ScreenDimensions.X / 2, 150), screenManager);

            //Add a consequence to selecting the items
            item1.OnButtonSelect += new EventHandler<MenuObjectEventArgs>(item1_OnButtonSelect);
            item2.OnButtonSelect += new EventHandler<MenuObjectEventArgs>(item2_OnButtonSelect);

            //Add the items to the page
            AddItem(item1);
            AddItem(item2);
        }

        /// <summary>
        /// Consequence to selecting item1
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void item1_OnButtonSelect(object sender, MenuObjectEventArgs e)
        {
            //Add the game screen and remove this menu screen
            screenManager.AddScreen(new TestGameScreen());
            screenManager.RemoveScreen(this);
        }

        /// <summary>
        /// Consequence to selecting item2
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void item2_OnButtonSelect(object sender, MenuObjectEventArgs e)
        {
            ///Confirm to the player that they want to close the game using ConfirmMessageScreen
            ConfirmMessageScreen confirmScreen = new ConfirmMessageScreen("Close the game?");
            confirmScreen.OnConfirm += new EventHandler<EventArgs>(conirmScreen_OnConfirm);
            screenManager.AddScreen(confirmScreen);
        }

        /// <summary>
        /// Method used to close the game
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void conirmScreen_OnConfirm(object sender, EventArgs e)
        {
            screenManager.Game.Exit();
        }
    }
}
